@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Dist::Zilla::PluginBundle::MITHALDU;
-our $VERSION = '1.150520'; # VERSION
+our $VERSION = '1.150521'; # VERSION
 
 # Dependencies
 use autodie 2.00;
@@ -262,7 +262,7 @@ sub configure {
 
   # copy files from build back to root for inclusion in VCS
   [ CopyFilesFromBuild => {
-      map { ( copy => $_ ) } @generated_files
+      copy => \@generated_files
     }
   ],
 
@@ -333,7 +333,7 @@ Dist::Zilla::PluginBundle::MITHALDU - Dist::Zilla configuration the way MITHALDU
 
 =head1 VERSION
 
-version 1.150520
+version 1.150521
 
 =head1 SYNOPSIS
 
